CompositeDelegate

Struct CompositeDelegate 

pub struct CompositeDelegate<I, Address, A = VoidDelegate<I, Address>, C = VoidDelegate<I, Address>, E = VoidDelegate<I, Address>, M = VoidDelegate<I, Address>, N = VoidDelegate<I, Address>, P = VoidDelegate<I, Address>> { /* private fields */ }
CompositeDelegate is a helpful struct to split the Delegate into multiple small delegates, so that users do not need to implement full Delegate when they only want to custom some methods in the Delegate.

Implementations

Source

impl<I, Address> CompositeDelegate<I, Address>

pub const fn new() -> Self

Create a new CompositeDelegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_alive_delegate<NA>( self, alive_delegate: NA, ) -> CompositeDelegate<I, Address, NA, C, E, M, N, P>

Set the alive delegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_conflict_delegate<NC>( self, conflict_delegate: NC, ) -> CompositeDelegate<I, Address, A, NC, E, M, N, P>

Set the conflict delegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_event_delegate<NE>( self, event_delegate: NE, ) -> CompositeDelegate<I, Address, A, C, NE, M, N, P>

Set the event delegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_merge_delegate<NM>( self, merge_delegate: NM, ) -> CompositeDelegate<I, Address, A, C, E, NM, N, P>

Set the merge delegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_node_delegate<NN>( self, node_delegate: NN, ) -> CompositeDelegate<I, Address, A, C, E, M, NN, P>

Set the node delegate

Source

impl<I, Address, A, C, E, M, N, P> CompositeDelegate<I, Address, A, C, E, M, N, P>

pub fn with_ping_delegate<NP>( self, ping_delegate: NP, ) -> CompositeDelegate<I, Address, A, C, E, M, N, NP>

Set the ping delegate