pub struct SubscribleEventDelegate<I, A>(/* private fields */);Expand description
Used to enable an application to receive events about joins and leaves over a subscriber instead of a direct function call.
Implementations
Sourceimpl<I, A> SubscribleEventDelegate<I, A>
impl<I, A> SubscribleEventDelegate<I, A>
Sourcepub fn unbounded() -> (Self, EventSubscriber<I, A>)
pub fn unbounded() -> (Self, EventSubscriber<I, A>)
Creates a new EventDelegate and unbounded subscriber.
Sourcepub fn bounded(capacity: usize) -> (Self, EventSubscriber<I, A>)
pub fn bounded(capacity: usize) -> (Self, EventSubscriber<I, A>)
Creates a new EventDelegate and bounded subscriber.
Care must be taken that events are processed in a timely manner from the channel, since this delegate will block until an event can be sent.