EncryptionAlgorithm

Enum EncryptionAlgorithm 

#[non_exhaustive]
pub enum EncryptionAlgorithm { NoPadding, Pkcs7, Unknown(u8), }
Available on crate feature encryption only.
The encryption algorithm used to encrypt the message.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoPadding

AES-GCM, using no padding



Pkcs7

AES-GCM, using PKCS7 padding



Unknown(u8)

Unknwon encryption version

Implementations

Source

impl EncryptionAlgorithm

pub const fn is_no_padding(&self) -> bool

Returns true if this value is of type NoPadding. Returns false otherwise

pub const fn is_pkcs_7(&self) -> bool

Returns true if this value is of type Pkcs7. Returns false otherwise

pub const fn is_unknown(&self) -> bool

Returns true if this value is of type Unknown. Returns false otherwise

Source

impl EncryptionAlgorithm

pub const fn as_u8(&self) -> u8

Returns the encryption version as a u8.

pub fn as_str(&self) -> Cow<'static, str>

Returns the encryption version as a &'static str.

Source

impl EncryptionAlgorithm

pub const fn nonce_size(&self) -> usize

Returns the nonce size of the encryption algorithm

pub fn write_nonce(dst: &mut impl BufMut) -> [u8; 12]

Writes the nonce to the buffer, returning the random generated nonce

pub fn random_nonce() -> [u8; 12]

Generates a random nonce

pub fn read_nonce(src: &mut impl Buf) -> [u8; 12]

Reads the nonce from the buffer

pub fn encrypt<B>( &self, pk: SecretKey, nonce: [u8; 12], auth_data: &[u8], buf: &mut B, ) -> Result<(), EncryptionError>
where B: Buffer,

Encrypts the data using the provided secret key, nonce, and the authentication data

pub fn decrypt( &self, key: &SecretKey, nonce: &[u8], auth_data: &[u8], dst: &mut impl Buffer, ) -> Result<(), EncryptionError>

Decrypts the data using the provided secret key, nonce, and the authentication data

pub const fn encrypted_suffix_len(&self, inp: usize) -> usize

Returns the encrypted suffix length of the input size