ChecksumAlgorithm

Enum ChecksumAlgorithm 

#[non_exhaustive]
pub enum ChecksumAlgorithm { Crc32, XxHash32, XxHash64, XxHash3, Murmur3, Unknown(u8), }
The algorithm used to checksum the message.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Crc32

Available on crate feature crc32 only.

CRC32 IEEE



XxHash32

Available on crate feature xxhash32 only.

XXHash32



XxHash64

Available on crate feature xxhash64 only.

XXHash64



XxHash3

Available on crate feature xxhash3 only.

XXHash3



Murmur3

Available on crate feature murmur3 only.

Murmur3



Unknown(u8)

Unknwon checksum algorithm

Implementations

Source

impl ChecksumAlgorithm

pub const fn is_crc_32(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type Crc32. Returns false otherwise

pub const fn is_xx_hash_32(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type XxHash32. Returns false otherwise

pub const fn is_xx_hash_64(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type XxHash64. Returns false otherwise

pub const fn is_xx_hash_3(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type XxHash3. Returns false otherwise

pub const fn is_murmur_3(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type Murmur3. Returns false otherwise

pub const fn is_unknown(&self) -> bool

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns true if this value is of type Unknown. Returns false otherwise

Source

impl ChecksumAlgorithm

pub const fn as_u8(&self) -> u8

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns the checksum algorithm as a u8.

pub fn as_str(&self) -> Cow<'static, str>

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns the checksum algorithm as a &'static str.

pub const fn output_size(&self) -> usize

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Returns the output size of the checksum algorithm.

Source

impl ChecksumAlgorithm

pub fn checksum(&self, data: &[u8]) -> Result<u64, ChecksumError>

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Calculate the checksum of the data using the specified algorithm.