DecodeError

Enum DecodeError 

pub enum DecodeError {
    BufferUnderflow,
    MissingField {
        ty: &'static str,
        field: &'static str,
    },
    DuplicateField {
        ty: &'static str,
        field: &'static str,
        tag: u8,
    },
    UnknownWireType {
        ty: &'static str,
        value: u8,
        tag: u8,
    },
    UnknownTag {
        ty: &'static str,
        tag: u8,
    },
    LengthDelimitedOverflow,
    Custom(Cow<'static, str>),
}
A message decoding error.

DecodeError indicates that the input buffer does not contain a valid message. The error details should be considered ‘best effort’: in general it is not possible to exactly pinpoint why data is malformed.

Variants



BufferUnderflow

Returned when the buffer does not have enough data to decode the message.



MissingField

Returned when the buffer does not contain the required field.

Fields

ty: &'static str

The type of the message.

field: &'static str

The name of the field.



DuplicateField

Returned when the buffer contains duplicate fields for the same tag in a message.

Fields

ty: &'static str

The type of the message.

field: &'static str

The name of the field.

tag: u8

The tag of the field.



UnknownWireType

Returned when there is a unknown wire type.

Fields

ty: &'static str

The type of the message.

value: u8

The unknown wire type value.

tag: u8

The tag of the field.



UnknownTag

Returned when finding a unknown tag.

Fields

ty: &'static str

The type of the message.

tag: u8

The unknown tag value.



LengthDelimitedOverflow

Returned when fail to decode the length-delimited



Custom(Cow<'static, str>)

A custom decoding error.

Implementations

Source

impl DecodeError

pub const fn is_buffer_underflow(&self) -> bool

Returns true if this value is of type BufferUnderflow. Returns false otherwise

pub const fn is_missing_field(&self) -> bool

Returns true if this value is of type MissingField. Returns false otherwise

pub const fn is_duplicate_field(&self) -> bool

Returns true if this value is of type DuplicateField. Returns false otherwise

pub const fn is_unknown_wire_type(&self) -> bool

Returns true if this value is of type UnknownWireType. Returns false otherwise

pub const fn is_unknown_tag(&self) -> bool

Returns true if this value is of type UnknownTag. Returns false otherwise

pub const fn is_length_delimited_overflow(&self) -> bool

Returns true if this value is of type LengthDelimitedOverflow. Returns false otherwise

pub const fn is_custom(&self) -> bool

Returns true if this value is of type Custom. Returns false otherwise

Source

impl DecodeError

pub const fn buffer_underflow() -> DecodeError

Creates a new buffer underflow decoding error.

pub const fn missing_field(ty: &'static str, field: &'static str) -> DecodeError

Creates a new missing field decoding error.

pub const fn duplicate_field( ty: &'static str, field: &'static str, tag: u8, ) -> DecodeError

Creates a new duplicate field decoding error.

pub const fn unknown_wire_type( ty: &'static str, value: u8, tag: u8, ) -> DecodeError

Creates a new unknown wire type decoding error.

pub const fn unknown_tag(ty: &'static str, tag: u8) -> DecodeError

Creates a new unknown tag decoding error.

pub fn custom<T>(value: T) -> DecodeError
where T: Into<Cow<'static, str>>,

Creates a custom decoding error.