#[non_exhaustive]pub enum EncryptionAlgorithm {
NoPadding,
Pkcs7,
Unknown(u8),
}Expand description
The encryption algorithm used to encrypt the message.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoPadding
AES-GCM, using no padding
Pkcs7
AES-GCM, using PKCS7 padding
Unknown(u8)
Unknwon encryption version
Implementations
Sourceimpl EncryptionAlgorithm
impl EncryptionAlgorithm
Sourcepub const fn is_no_padding(&self) -> bool
Available on crate feature encryption only.
pub const fn is_no_padding(&self) -> bool
encryption only.Returns true if this value is of type NoPadding. Returns false otherwise
Sourcepub const fn is_pkcs_7(&self) -> bool
Available on crate feature encryption only.
pub const fn is_pkcs_7(&self) -> bool
encryption only.Returns true if this value is of type Pkcs7. Returns false otherwise
Sourcepub const fn is_unknown(&self) -> bool
Available on crate feature encryption only.
pub const fn is_unknown(&self) -> bool
encryption only.Returns true if this value is of type Unknown. Returns false otherwise
Sourceimpl EncryptionAlgorithm
impl EncryptionAlgorithm
Sourcepub const fn nonce_size(&self) -> usize
Available on crate feature encryption only.
pub const fn nonce_size(&self) -> usize
encryption only.Returns the nonce size of the encryption algorithm
Sourcepub fn write_nonce(dst: &mut impl BufMut) -> [u8; 12]
Available on crate feature encryption only.
pub fn write_nonce(dst: &mut impl BufMut) -> [u8; 12]
encryption only.Writes the nonce to the buffer, returning the random generated nonce
Sourcepub fn random_nonce() -> [u8; 12]
Available on crate feature encryption only.
pub fn random_nonce() -> [u8; 12]
encryption only.Generates a random nonce
Sourcepub fn read_nonce(src: &mut impl Buf) -> [u8; 12]
Available on crate feature encryption only.
pub fn read_nonce(src: &mut impl Buf) -> [u8; 12]
encryption only.Reads the nonce from the buffer
Sourcepub fn encrypt<B>(
&self,
pk: SecretKey,
nonce: [u8; 12],
auth_data: &[u8],
buf: &mut B,
) -> Result<(), EncryptionError>where
B: Buffer,
Available on crate feature encryption only.
pub fn encrypt<B>(
&self,
pk: SecretKey,
nonce: [u8; 12],
auth_data: &[u8],
buf: &mut B,
) -> Result<(), EncryptionError>where
B: Buffer,
encryption only.Encrypts the data using the provided secret key, nonce, and the authentication data
Sourcepub fn decrypt(
&self,
key: &SecretKey,
nonce: &[u8],
auth_data: &[u8],
dst: &mut impl Buffer,
) -> Result<(), EncryptionError>
Available on crate feature encryption only.
pub fn decrypt( &self, key: &SecretKey, nonce: &[u8], auth_data: &[u8], dst: &mut impl Buffer, ) -> Result<(), EncryptionError>
encryption only.Decrypts the data using the provided secret key, nonce, and the authentication data
Sourcepub const fn encrypted_suffix_len(&self, inp: usize) -> usize
Available on crate feature encryption only.
pub const fn encrypted_suffix_len(&self, inp: usize) -> usize
encryption only.Returns the encrypted suffix length of the input size