MaybeResolvedAddress

Enum MaybeResolvedAddress 

pub enum MaybeResolvedAddress<A, R> {
    Resolved(R),
    Unresolved(A),
}
MaybeResolvedAddress is used to represent an address that may or may not be resolved.

Variants



Resolved(R)

The resolved address, which means that can be directly used to communicate with the remote node.



Unresolved(A)

The unresolved address, which means that need to be resolved before using it to communicate with the remote node.

Implementations

Source

impl<A, R> MaybeResolvedAddress<A, R>

pub fn try_unwrap_resolved( self, ) -> Result<R, TryUnwrapError<MaybeResolvedAddress<A, R>>>

Attempts to unwrap this value to the MaybeResolvedAddress::Resolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_resolved_ref( &self, ) -> Result<&R, TryUnwrapError<&MaybeResolvedAddress<A, R>>>

Attempts to unwrap this reference to the MaybeResolvedAddress::Resolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_resolved_mut( &mut self, ) -> Result<&mut R, TryUnwrapError<&mut MaybeResolvedAddress<A, R>>>

Attempts to unwrap this mutable reference to the MaybeResolvedAddress::Resolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_unresolved( self, ) -> Result<A, TryUnwrapError<MaybeResolvedAddress<A, R>>>

Attempts to unwrap this value to the MaybeResolvedAddress::Unresolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_unresolved_ref( &self, ) -> Result<&A, TryUnwrapError<&MaybeResolvedAddress<A, R>>>

Attempts to unwrap this reference to the MaybeResolvedAddress::Unresolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_unresolved_mut( &mut self, ) -> Result<&mut A, TryUnwrapError<&mut MaybeResolvedAddress<A, R>>>

Attempts to unwrap this mutable reference to the MaybeResolvedAddress::Unresolved variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

Source

impl<A, R> MaybeResolvedAddress<A, R>

pub fn unwrap_resolved(self) -> R

Unwraps this value to the MaybeResolvedAddress::Resolved variant. Panics if this value is of any other type.

pub fn unwrap_resolved_ref(&self) -> &R

Unwraps this reference to the MaybeResolvedAddress::Resolved variant. Panics if this value is of any other type.

pub fn unwrap_resolved_mut(&mut self) -> &mut R

Unwraps this mutable reference to the MaybeResolvedAddress::Resolved variant. Panics if this value is of any other type.

pub fn unwrap_unresolved(self) -> A

Unwraps this value to the MaybeResolvedAddress::Unresolved variant. Panics if this value is of any other type.

pub fn unwrap_unresolved_ref(&self) -> &A

Unwraps this reference to the MaybeResolvedAddress::Unresolved variant. Panics if this value is of any other type.

pub fn unwrap_unresolved_mut(&mut self) -> &mut A

Unwraps this mutable reference to the MaybeResolvedAddress::Unresolved variant. Panics if this value is of any other type.

Source

impl<A, R> MaybeResolvedAddress<A, R>

pub const fn is_resolved(&self) -> bool

Returns true if this value is of type Resolved. Returns false otherwise

pub const fn is_unresolved(&self) -> bool

Returns true if this value is of type Unresolved. Returns false otherwise

Source

impl<A, R> MaybeResolvedAddress<A, R>

pub const fn resolved(addr: R) -> MaybeResolvedAddress<A, R>

Creates a resolved address.

pub const fn unresolved(addr: A) -> MaybeResolvedAddress<A, R>

Creates an unresolved address.

pub const fn as_ref(&self) -> MaybeResolvedAddress<&A, &R>

Converts from &MaybeResolvedAddress<A, R> to MaybeResolvedAddress<&A, &R>.

pub const fn as_mut(&mut self) -> MaybeResolvedAddress<&mut A, &mut R>

Converts from &mut MaybeResolvedAddress<A, R> to MaybeResolvedAddress<&mut A, &mut R>.