#[non_exhaustive]pub enum Message<I, A> {
Ping(Ping<I, A>),
IndirectPing(IndirectPing<I, A>),
Ack(Ack),
Suspect(Suspect<I>),
Alive(Alive<I, A>),
Dead(Dead<I>),
PushPull(PushPull<I, A>),
UserData(Bytes),
Nack(Nack),
ErrorResponse(ErrorResponse),
}Expand description
Request to be sent to the Raft node.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ping(Ping<I, A>)
Ping message
IndirectPing(IndirectPing<I, A>)
Indirect ping message
Ack(Ack)
Ack response message
Suspect(Suspect<I>)
Suspect message
Alive(Alive<I, A>)
Alive message
Dead(Dead<I>)
Dead message
PushPull(PushPull<I, A>)
PushPull message
UserData(Bytes)
User mesg, not handled by us
Nack(Nack)
Nack response message
ErrorResponse(ErrorResponse)
Error response message
Implementations
Sourceimpl<I, A> Message<I, A>
impl<I, A> Message<I, A>
Sourcepub const fn is_ping(&self) -> bool
pub const fn is_ping(&self) -> bool
Returns true if this value is of type Ping. Returns false otherwise
Sourcepub const fn is_indirect_ping(&self) -> bool
pub const fn is_indirect_ping(&self) -> bool
Returns true if this value is of type IndirectPing. Returns false otherwise
Sourcepub const fn is_ack(&self) -> bool
pub const fn is_ack(&self) -> bool
Returns true if this value is of type Ack. Returns false otherwise
Sourcepub const fn is_suspect(&self) -> bool
pub const fn is_suspect(&self) -> bool
Returns true if this value is of type Suspect. Returns false otherwise
Sourcepub const fn is_alive(&self) -> bool
pub const fn is_alive(&self) -> bool
Returns true if this value is of type Alive. Returns false otherwise
Sourcepub const fn is_dead(&self) -> bool
pub const fn is_dead(&self) -> bool
Returns true if this value is of type Dead. Returns false otherwise
Sourcepub const fn is_push_pull(&self) -> bool
pub const fn is_push_pull(&self) -> bool
Returns true if this value is of type PushPull. Returns false otherwise
Sourcepub const fn is_user_data(&self) -> bool
pub const fn is_user_data(&self) -> bool
Returns true if this value is of type UserData. Returns false otherwise
Sourcepub const fn is_nack(&self) -> bool
pub const fn is_nack(&self) -> bool
Returns true if this value is of type Nack. Returns false otherwise
Sourcepub const fn is_error_response(&self) -> bool
pub const fn is_error_response(&self) -> bool
Returns true if this value is of type ErrorResponse. Returns false otherwise
Sourceimpl<I, A> Message<I, A>
impl<I, A> Message<I, A>
Sourcepub fn unwrap_ping(self) -> Ping<I, A>
pub fn unwrap_ping(self) -> Ping<I, A>
Unwraps this value to the Message::Ping variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_indirect_ping(self) -> IndirectPing<I, A>
pub fn unwrap_indirect_ping(self) -> IndirectPing<I, A>
Unwraps this value to the Message::IndirectPing variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_ack(self) -> Ack
pub fn unwrap_ack(self) -> Ack
Unwraps this value to the Message::Ack variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_suspect(self) -> Suspect<I>
pub fn unwrap_suspect(self) -> Suspect<I>
Unwraps this value to the Message::Suspect variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_alive(self) -> Alive<I, A>
pub fn unwrap_alive(self) -> Alive<I, A>
Unwraps this value to the Message::Alive variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_dead(self) -> Dead<I>
pub fn unwrap_dead(self) -> Dead<I>
Unwraps this value to the Message::Dead variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_push_pull(self) -> PushPull<I, A>
pub fn unwrap_push_pull(self) -> PushPull<I, A>
Unwraps this value to the Message::PushPull variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_user_data(self) -> Bytes
pub fn unwrap_user_data(self) -> Bytes
Unwraps this value to the Message::UserData variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_nack(self) -> Nack
pub fn unwrap_nack(self) -> Nack
Unwraps this value to the Message::Nack variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_error_response(self) -> ErrorResponse
pub fn unwrap_error_response(self) -> ErrorResponse
Unwraps this value to the Message::ErrorResponse variant.
Panics if this value is of any other type.
Sourceimpl<I, A> Message<I, A>
impl<I, A> Message<I, A>
Sourcepub fn try_unwrap_ping(
self,
) -> Result<Ping<I, A>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_ping( self, ) -> Result<Ping<I, A>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Ping variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_indirect_ping(
self,
) -> Result<IndirectPing<I, A>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_indirect_ping( self, ) -> Result<IndirectPing<I, A>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::IndirectPing variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_ack(self) -> Result<Ack, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_ack(self) -> Result<Ack, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Ack variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_suspect(
self,
) -> Result<Suspect<I>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_suspect( self, ) -> Result<Suspect<I>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Suspect variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_alive(
self,
) -> Result<Alive<I, A>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_alive( self, ) -> Result<Alive<I, A>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Alive variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_dead(self) -> Result<Dead<I>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_dead(self) -> Result<Dead<I>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Dead variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_push_pull(
self,
) -> Result<PushPull<I, A>, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_push_pull( self, ) -> Result<PushPull<I, A>, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::PushPull variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_user_data(
self,
) -> Result<Bytes, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_user_data( self, ) -> Result<Bytes, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::UserData variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_nack(self) -> Result<Nack, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_nack(self) -> Result<Nack, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::Nack variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_error_response(
self,
) -> Result<ErrorResponse, TryUnwrapError<Message<I, A>>>
pub fn try_unwrap_error_response( self, ) -> Result<ErrorResponse, TryUnwrapError<Message<I, A>>>
Attempts to unwrap this value to the Message::ErrorResponse variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourceimpl<I, A> Message<I, A>
impl<I, A> Message<I, A>
Sourcepub const fn ty(&self) -> MessageType
pub const fn ty(&self) -> MessageType
Returns the type of the message.
Sourcepub const fn indirect_ping(val: IndirectPing<I, A>) -> Message<I, A>
pub const fn indirect_ping(val: IndirectPing<I, A>) -> Message<I, A>
Construct a Message from IndirectPing.
Sourcepub const fn error_response(val: ErrorResponse) -> Message<I, A>
pub const fn error_response(val: ErrorResponse) -> Message<I, A>
Construct a Message from ErrorResponse.