MessageRef

Enum MessageRef 

pub enum MessageRef<'a, I, A> {
    Ping(Ping<I, A>),
    IndirectPing(IndirectPing<I, A>),
    Ack(AckRef<'a>),
    Suspect(Suspect<I>),
    Alive(AliveRef<'a, I, A>),
    Dead(Dead<I>),
    PushPull(PushPullRef<'a, I, A>),
    UserData(&'a [u8]),
    Nack(Nack),
    ErrorResponse(ErrorResponseRef<'a>),
}
The reference type of the Message enum.

Variants



Ping(Ping<I, A>)

Ping message



IndirectPing(IndirectPing<I, A>)

Indirect ping message



Ack(AckRef<'a>)

Ack response message



Suspect(Suspect<I>)

Suspect message



Alive(AliveRef<'a, I, A>)

Alive message



Dead(Dead<I>)

Dead message



PushPull(PushPullRef<'a, I, A>)

PushPull message



UserData(&'a [u8])

User mesg, not handled by us



Nack(Nack)

Nack response message



ErrorResponse(ErrorResponseRef<'a>)

Error response message

Implementations

Source

impl<I, A> MessageRef<'_, I, A>

pub const fn ty(&self) -> MessageType

Returns the type of the message.

Source

impl<'a, I, A> MessageRef<'a, I, A>

pub const fn is_ping(&self) -> bool

Returns true if this value is of type Ping. Returns false otherwise

pub const fn is_indirect_ping(&self) -> bool

Returns true if this value is of type IndirectPing. Returns false otherwise

pub const fn is_ack(&self) -> bool

Returns true if this value is of type Ack. Returns false otherwise

pub const fn is_suspect(&self) -> bool

Returns true if this value is of type Suspect. Returns false otherwise

pub const fn is_alive(&self) -> bool

Returns true if this value is of type Alive. Returns false otherwise

pub const fn is_dead(&self) -> bool

Returns true if this value is of type Dead. Returns false otherwise

pub const fn is_push_pull(&self) -> bool

Returns true if this value is of type PushPull. Returns false otherwise

pub const fn is_user_data(&self) -> bool

Returns true if this value is of type UserData. Returns false otherwise

pub const fn is_nack(&self) -> bool

Returns true if this value is of type Nack. Returns false otherwise

pub const fn is_error_response(&self) -> bool

Returns true if this value is of type ErrorResponse. Returns false otherwise

Source

impl<'a, I, A> MessageRef<'a, I, A>

pub fn unwrap_ping(self) -> Ping<I, A>

Unwraps this value to the MessageRef::Ping variant. Panics if this value is of any other type.

pub fn unwrap_indirect_ping(self) -> IndirectPing<I, A>

Unwraps this value to the MessageRef::IndirectPing variant. Panics if this value is of any other type.

pub fn unwrap_ack(self) -> AckRef<'a>

Unwraps this value to the MessageRef::Ack variant. Panics if this value is of any other type.

pub fn unwrap_suspect(self) -> Suspect<I>

Unwraps this value to the MessageRef::Suspect variant. Panics if this value is of any other type.

pub fn unwrap_alive(self) -> AliveRef<'a, I, A>

Unwraps this value to the MessageRef::Alive variant. Panics if this value is of any other type.

pub fn unwrap_dead(self) -> Dead<I>

Unwraps this value to the MessageRef::Dead variant. Panics if this value is of any other type.

pub fn unwrap_push_pull(self) -> PushPullRef<'a, I, A>

Unwraps this value to the MessageRef::PushPull variant. Panics if this value is of any other type.

pub fn unwrap_user_data(self) -> &'a [u8]

Unwraps this value to the MessageRef::UserData variant. Panics if this value is of any other type.

pub fn unwrap_nack(self) -> Nack

Unwraps this value to the MessageRef::Nack variant. Panics if this value is of any other type.

pub fn unwrap_error_response(self) -> ErrorResponseRef<'a>

Unwraps this value to the MessageRef::ErrorResponse variant. Panics if this value is of any other type.

Source

impl<'a, I, A> MessageRef<'a, I, A>

pub fn try_unwrap_ping( self, ) -> Result<Ping<I, A>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Ping variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_indirect_ping( self, ) -> Result<IndirectPing<I, A>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::IndirectPing variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_ack( self, ) -> Result<AckRef<'a>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Ack variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_suspect( self, ) -> Result<Suspect<I>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Suspect variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_alive( self, ) -> Result<AliveRef<'a, I, A>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Alive variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_dead( self, ) -> Result<Dead<I>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Dead variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_push_pull( self, ) -> Result<PushPullRef<'a, I, A>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::PushPull variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_user_data( self, ) -> Result<&'a [u8], TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::UserData variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_nack( self, ) -> Result<Nack, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::Nack variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_error_response( self, ) -> Result<ErrorResponseRef<'a>, TryUnwrapError<MessageRef<'a, I, A>>>

Attempts to unwrap this value to the MessageRef::ErrorResponse variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.