#[non_exhaustive]pub enum State {
Alive,
Suspect,
Dead,
Left,
Unknown(u8),
}Expand description
State for the memberlist
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Alive
Alive state
Suspect
Suspect state
Dead
Dead state
Left
Left state
Unknown(u8)
Unknown state (used for forwards and backwards compatibility)
Implementations
Sourceimpl State
impl State
Sourcepub const fn is_alive(&self) -> bool
pub const fn is_alive(&self) -> bool
Returns true if this value is of type Alive. Returns false otherwise
Sourcepub const fn is_suspect(&self) -> bool
pub const fn is_suspect(&self) -> bool
Returns true if this value is of type Suspect. Returns false otherwise
Sourcepub const fn is_dead(&self) -> bool
pub const fn is_dead(&self) -> bool
Returns true if this value is of type Dead. Returns false otherwise
Sourcepub const fn is_left(&self) -> bool
pub const fn is_left(&self) -> bool
Returns true if this value is of type Left. Returns false otherwise
Sourcepub const fn is_unknown(&self) -> bool
pub const fn is_unknown(&self) -> bool
Returns true if this value is of type Unknown. Returns false otherwise