pub struct AliveRef<'a, I, A> { /* private fields */ }Expand description
The reference type of Alive.
Implementations
Sourceimpl<'a, I, A> AliveRef<'a, I, A>
impl<'a, I, A> AliveRef<'a, I, A>
Sourcepub const fn incarnation(&self) -> u32
pub const fn incarnation(&self) -> u32
Returns the incarnation of the alive message.
Sourcepub const fn protocol_version(&self) -> ProtocolVersion
pub const fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the alive message is speaking.
Sourcepub const fn delegate_version(&self) -> DelegateVersion
pub const fn delegate_version(&self) -> DelegateVersion
Returns the delegate version of the alive message is speaking.