NodeState

Struct NodeState 

pub struct NodeState<I, A> {
    pub id: I,
    pub addr: A,
    pub meta: Meta,
    pub state: State,
    pub protocol_version: ProtocolVersion,
    pub delegate_version: DelegateVersion,
}
Represents a node in the cluster

Fields

id: I

The id of the node.

addr: A

The address of the node.

meta: Meta

Metadata from the delegate for this node.

state: State

State of the node.

protocol_version: ProtocolVersion

The protocol version of the node is speaking.

delegate_version: DelegateVersion

The delegate version of the node is speaking.

Implementations

Source

impl<I, A> NodeState<I, A>

pub const fn id(&self) -> &I

Returns the id of the node

pub const fn address(&self) -> &A

Returns the address of the node

pub const fn meta(&self) -> &Meta

Returns the meta of the node

pub const fn state(&self) -> State

Returns the state of the node

pub const fn protocol_version(&self) -> ProtocolVersion

Returns the protocol version of the node is speaking

pub const fn delegate_version(&self) -> DelegateVersion

Returns the delegate version of the node is speaking

pub fn with_id(self, val: I) -> NodeState<I, A>

Sets the id of the node (Builder pattern)

pub fn with_address(self, val: A) -> NodeState<I, A>

Sets the address of the node (Builder pattern)

pub fn with_meta(self, val: Meta) -> NodeState<I, A>

Sets the meta of the node (Builder pattern)

pub const fn with_state(self, val: State) -> NodeState<I, A>

Sets the state of the node (Builder pattern)

pub const fn with_protocol_version( self, val: ProtocolVersion, ) -> NodeState<I, A>

Sets the protocol version of the node is speaking (Builder pattern)

pub const fn with_delegate_version( self, val: DelegateVersion, ) -> NodeState<I, A>

Sets the delegate version of the node is speaking (Builder pattern)

Source

impl<I, A> NodeState<I, A>

pub const fn new(id: I, addr: A, state: State) -> NodeState<I, A>

Construct a new node with the given name, address and state.

pub fn set_id(&mut self, id: I) -> &mut NodeState<I, A>

Sets the id of the node state

pub fn set_address(&mut self, addr: A) -> &mut NodeState<I, A>

Sets the address of the node state

pub fn set_meta(&mut self, meta: Meta) -> &mut NodeState<I, A>

Sets the metadata for the node.

pub fn set_state(&mut self, state: State) -> &mut NodeState<I, A>

Sets the state for the node.

pub fn set_protocol_version( &mut self, protocol_version: ProtocolVersion, ) -> &mut NodeState<I, A>

Set the protocol version of the alive message is speaking.

pub fn set_delegate_version( &mut self, delegate_version: DelegateVersion, ) -> &mut NodeState<I, A>

Set the delegate version of the alive message is speaking.

Source

impl<I, A> NodeState<I, A>
where I: CheapClone, A: CheapClone,

pub fn node(&self) -> Node<I, A>

Returns a Node with the same id and address as this NodeState.