pub struct NodeStateRef<'a, I, A> {
pub id: I,
pub addr: A,
pub meta: &'a [u8],
pub state: State,
pub protocol_version: ProtocolVersion,
pub delegate_version: DelegateVersion,
}Expand description
The reference type for NodeState.
Fields
id: IThe id of the node.
addr: AThe address of the node.
meta: &'a [u8]Metadata from the delegate for this node.
state: StateState of the node.
protocol_version: ProtocolVersionThe protocol version of the node is speaking.
delegate_version: DelegateVersionThe delegate version of the node is speaking.
Implementations
Sourceimpl<'a, I, A> NodeStateRef<'a, I, A>
impl<'a, I, A> NodeStateRef<'a, I, A>
Sourcepub const fn protocol_version(&self) -> ProtocolVersion
pub const fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the node is speaking
Sourcepub const fn delegate_version(&self) -> DelegateVersion
pub const fn delegate_version(&self) -> DelegateVersion
Returns the delegate version of the node is speaking