pub struct Payload { /* private fields */ }Expand description
A payload can be sent over the transport.
Implementations
Sourceimpl Payload
impl Payload
Sourcepub fn new(header_size: usize, data_size: usize) -> Payload
pub fn new(header_size: usize, data_size: usize) -> Payload
Creates a new payload with the given buffer.
Sourcepub fn header_mut(&mut self) -> &mut [u8] ⓘ
pub fn header_mut(&mut self) -> &mut [u8] ⓘ
Returns the mutable header section of the payload.
Sourcepub fn truncate(&mut self, len: usize)
pub fn truncate(&mut self, len: usize)
Truncate the payload to the given length.
This will truncate the data section of the payload, the header section will not be affected.
Sourcepub fn split_mut(&mut self) -> (&mut [u8], &mut [u8])
pub fn split_mut(&mut self) -> (&mut [u8], &mut [u8])
Split the payload into header and data.
The first element of the tuple is the header and the second element is the data.
Sourcepub fn split(self) -> (BytesMut, BytesMut)
pub fn split(self) -> (BytesMut, BytesMut)
Split the payload into header and data.
The first element of the tuple is the header and the second element is the data.
Sourcepub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Consumes the payload and returns its inner buffer as a Bytes.
This is zero-copy when this is the only reference to the buffer (which is the common case for freshly-created payloads).