ProtoDecoder

Struct ProtoDecoder 

pub struct ProtoDecoder { /* private fields */ }
A protocol decoder.

Unlike the ProtoEncoder, the decoder will only check label, decrypt, decompress, and verify the checksum of the message. It will not decode the message itself, if you want to decode messages, use the [MessagesDecoder::new(payload)], the payload is what the ProtoDecoder::decode returns.

Implementations

Source

impl ProtoDecoder

pub const fn new() -> ProtoDecoder

Creates a new messages encoder.

pub fn with_label(&mut self, label: Label) -> &mut ProtoDecoder

Feeds the encoder with a label.

pub fn maybe_label(&mut self, label: Option<Label>) -> &mut ProtoDecoder

Feeds or clears the label.

pub fn without_label(&mut self) -> &mut ProtoDecoder

Clears the label.

pub fn with_verify_incoming(&mut self, verify: bool) -> &mut ProtoDecoder

Available on crate feature encryption only.

Feeds the decoder with a verification flag.

When set to true, the decoder will verify the incoming message (the incoming message must be encrypted).

pub fn with_offload_size(&mut self, size: usize) -> &mut ProtoDecoder

Available on crate features brotli or encryption or lz4 or snappy or zstd only.

Feeds the offload size.

pub fn with_encryption( &mut self, encrypt: impl Into<Arc<[SecretKey]>>, ) -> &mut ProtoDecoder

Available on crate feature encryption only.

Feeds the encoder with an encryption keys.

pub fn maybe_encryption( &mut self, encrypt: Option<impl Into<Arc<[SecretKey]>>>, ) -> &mut ProtoDecoder

Available on crate feature encryption only.

Feeds or clears the encryption keys.

pub fn without_encryption(&mut self) -> &mut ProtoDecoder

Available on crate feature encryption only.

Clears the encryption keys.

pub async fn decode_from_reader<R, RT>( &self, reader: &mut R, ) -> Result<Bytes, Error>
where R: ProtoReader + Unpin, RT: RuntimeLite,

Decode the message from the reader.

pub async fn decode<RT>( &self, buf: BytesMut, ) -> Result<Bytes, ProtoDecoderError>
where RT: RuntimeLite,

Decodes the to plain message bytes