ProtoEncoder

Struct ProtoEncoder 

pub struct ProtoEncoder<I, A, M> { /* private fields */ }
The encoder of messages

Implementations

Source

impl<I, A, B> ProtoEncoder<I, A, B>
where I: Data + 'static, A: Data + 'static, B: AsRef<[Message<I, A>]> + Send + Sync + 'static,

pub async fn blocking_encode<RT>( self, ) -> impl Iterator<Item = Result<Payload, ProtoEncoderError>> + 'static
where RT: RuntimeLite,

Encodes the messages.

Source

impl<I, A, B> ProtoEncoder<I, A, B>
where I: Data, A: Data, B: AsRef<[Message<I, A>]> + Send + Sync,

pub fn rayon_encode( &self, ) -> impl ParallelIterator<Item = Result<Payload, ProtoEncoderError>> + Debug

Encodes the messages.

Source

impl<I, A> ProtoEncoder<I, A, &'static [u8]>

pub const fn new(max_payload_size: usize) -> ProtoEncoder<I, A, &'static [u8]>

Creates a new messages encoder.

Source

impl<I, A, M> ProtoEncoder<I, A, M>

pub fn into_messages(self) -> M

Consumes the encoder and returns the messages.

pub fn messages(&self) -> &M

Returns the messages in the encoder.

pub fn with_overhead(self, overhead: usize) -> ProtoEncoder<I, A, M>

Feeds the overhead for this encoder.

pub fn overhead(&self) -> usize

Returns the overhead of the encoder.

pub fn with_messages<NB>(self, msgs: NB) -> ProtoEncoder<I, A, NB>
where I: Data, A: Data, NB: AsRef<[Message<I, A>]>,

Feeds the encoder with messages.

Source

impl<I, A, M> ProtoEncoder<I, A, M>

pub fn with_label(self, label: Label) -> ProtoEncoder<I, A, M>

Feeds the encoder with a label.

pub const fn with_checksum( self, checksum: ChecksumAlgorithm, ) -> ProtoEncoder<I, A, M>

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Feeds the encoder with a checksum algorithm.

pub const fn maybe_checksum( &mut self, checksum: Option<ChecksumAlgorithm>, ) -> &mut ProtoEncoder<I, A, M>

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Feeds or clear the checksum related settings for the encoder.

pub const fn without_checksum(self) -> ProtoEncoder<I, A, M>

Available on crate features crc32 or murmur3 or xxhash32 or xxhash3 or xxhash64 only.

Clears the checksum related settings.

pub const fn with_compression( self, compress: CompressAlgorithm, ) -> ProtoEncoder<I, A, M>

Available on crate features brotli or lz4 or snappy or zstd only.

Feeds the encoder with a compression algorithm.

pub const fn maybe_compression( &mut self, compress: Option<CompressAlgorithm>, ) -> &mut ProtoEncoder<I, A, M>

Available on crate features brotli or lz4 or snappy or zstd only.

Feeds or clear the compression related settings for the encoder.

pub const fn without_compression(self) -> ProtoEncoder<I, A, M>

Available on crate features brotli or lz4 or snappy or zstd only.

Clears the compression related settings.

pub const fn with_compression_threshold( self, compression_threshold: usize, ) -> ProtoEncoder<I, A, M>

Available on crate features brotli or lz4 or snappy or zstd only.

Feeds the encoder with a minimum compression size.

If the payload size is less than this value, the encoder will not compress the payload.

Default is 512 bytes. The minimum value is 32 bytes.

pub const fn with_encryption( self, algo: EncryptionAlgorithm, key: SecretKey, ) -> ProtoEncoder<I, A, M>

Available on crate feature encryption only.

Feeds the encoder with an encryption algorithm.

pub const fn set_encryption( &mut self, algo: EncryptionAlgorithm, key: SecretKey, ) -> &mut ProtoEncoder<I, A, M>

Available on crate feature encryption only.

Feeds the encoder with an encryption algorithm.

pub const fn maybe_encryption( self, encrypt: Option<(EncryptionAlgorithm, SecretKey)>, ) -> ProtoEncoder<I, A, M>

Available on crate feature encryption only.

Feeds or clear the encryption related settings for the encoder.

pub const fn without_encryption(self) -> ProtoEncoder<I, A, M>

Available on crate feature encryption only.

Clears the encryption related settings.

Source

impl<I, A, M> ProtoEncoder<I, A, M>
where I: Data, A: Data, M: AsRef<[Message<I, A>]>,

pub fn hint(&self) -> Result<ProtoHint, ProtoEncoderError>

Returns the hint of how the encoder should process the messages.

pub fn hint_with_size( &self, input_size: usize, ) -> Result<ProtoHint, ProtoEncoderError>

Returns the hint of how the encoder should process the input size data.

pub fn encode( &self, ) -> impl Iterator<Item = Result<Payload, ProtoEncoderError>> + Debug

Encodes the messages.