pub struct PushNodeState<I, A> {
pub id: I,
pub addr: A,
pub meta: Meta,
pub incarnation: u32,
pub state: State,
pub protocol_version: ProtocolVersion,
pub delegate_version: DelegateVersion,
}Expand description
Push node state is the state push to the remote server.
Fields
id: IThe id of the push node state.
addr: AThe address of the push node state.
meta: MetaMetadata from the delegate for this push node state.
incarnation: u32The incarnation of the push node state.
state: StateThe state of the push node state.
protocol_version: ProtocolVersionThe protocol version of the push node state is speaking.
delegate_version: DelegateVersionThe delegate version of the push node state is speaking.
Implementations
Sourceimpl<I, A> PushNodeState<I, A>
impl<I, A> PushNodeState<I, A>
Sourcepub const fn incarnation(&self) -> u32
pub const fn incarnation(&self) -> u32
Returns the incarnation of the push node state
Sourcepub const fn protocol_version(&self) -> ProtocolVersion
pub const fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the push node state is speaking
Sourcepub const fn delegate_version(&self) -> DelegateVersion
pub const fn delegate_version(&self) -> DelegateVersion
Returns the delegate version of the push node state is speaking
Sourcepub fn with_id(self, val: I) -> PushNodeState<I, A>
pub fn with_id(self, val: I) -> PushNodeState<I, A>
Sets the id of the push node state (Builder pattern)
Sourcepub fn with_address(self, val: A) -> PushNodeState<I, A>
pub fn with_address(self, val: A) -> PushNodeState<I, A>
Sets the address of the push node state (Builder pattern)
Sourcepub fn with_meta(self, val: Meta) -> PushNodeState<I, A>
pub fn with_meta(self, val: Meta) -> PushNodeState<I, A>
Sets the meta of the push node state (Builder pattern)
Sourcepub const fn with_incarnation(self, val: u32) -> PushNodeState<I, A>
pub const fn with_incarnation(self, val: u32) -> PushNodeState<I, A>
Sets the incarnation of the push node state (Builder pattern)
Sourcepub const fn with_state(self, val: State) -> PushNodeState<I, A>
pub const fn with_state(self, val: State) -> PushNodeState<I, A>
Sets the state of the push node state (Builder pattern)
Sourcepub const fn with_protocol_version(
self,
val: ProtocolVersion,
) -> PushNodeState<I, A>
pub const fn with_protocol_version( self, val: ProtocolVersion, ) -> PushNodeState<I, A>
Sets the protocol version of the push node state is speaking (Builder pattern)
Sourcepub const fn with_delegate_version(
self,
val: DelegateVersion,
) -> PushNodeState<I, A>
pub const fn with_delegate_version( self, val: DelegateVersion, ) -> PushNodeState<I, A>
Sets the delegate version of the push node state is speaking (Builder pattern)
Sourceimpl<I, A> PushNodeState<I, A>
impl<I, A> PushNodeState<I, A>
Sourcepub const fn new(
incarnation: u32,
id: I,
addr: A,
state: State,
) -> PushNodeState<I, A>
pub const fn new( incarnation: u32, id: I, addr: A, state: State, ) -> PushNodeState<I, A>
Construct a new push node state with the given id, address and state.
Sourcepub fn set_id(&mut self, id: I) -> &mut PushNodeState<I, A>
pub fn set_id(&mut self, id: I) -> &mut PushNodeState<I, A>
Sets the id of the push node state
Sourcepub fn set_address(&mut self, addr: A) -> &mut PushNodeState<I, A>
pub fn set_address(&mut self, addr: A) -> &mut PushNodeState<I, A>
Sets the address of the push node state
Sourcepub fn set_meta(&mut self, meta: Meta) -> &mut PushNodeState<I, A>
pub fn set_meta(&mut self, meta: Meta) -> &mut PushNodeState<I, A>
Sets the meta of the push node state
Sourcepub fn set_incarnation(&mut self, incarnation: u32) -> &mut PushNodeState<I, A>
pub fn set_incarnation(&mut self, incarnation: u32) -> &mut PushNodeState<I, A>
Sets the incarnation of the push node state
Sourcepub fn set_state(&mut self, state: State) -> &mut PushNodeState<I, A>
pub fn set_state(&mut self, state: State) -> &mut PushNodeState<I, A>
Sets the state of the push node state
Sourcepub fn set_protocol_version(
&mut self,
protocol_version: ProtocolVersion,
) -> &mut PushNodeState<I, A>
pub fn set_protocol_version( &mut self, protocol_version: ProtocolVersion, ) -> &mut PushNodeState<I, A>
Sets the protocol version of the push node state
Sourcepub fn set_delegate_version(
&mut self,
delegate_version: DelegateVersion,
) -> &mut PushNodeState<I, A>
pub fn set_delegate_version( &mut self, delegate_version: DelegateVersion, ) -> &mut PushNodeState<I, A>
Sets the delegate version of the push node state
Sourceimpl<I, A> PushNodeState<I, A>where
I: CheapClone,
A: CheapClone,
impl<I, A> PushNodeState<I, A>where
I: CheapClone,
A: CheapClone,
Sourcepub fn node(&self) -> Node<I, A>
pub fn node(&self) -> Node<I, A>
Returns a Node with the same id and address as this PushNodeState.