pub struct PushNodeStateRef<'a, I, A> {
pub id: I,
pub addr: A,
pub meta: &'a [u8],
pub incarnation: u32,
pub state: State,
pub protocol_version: ProtocolVersion,
pub delegate_version: DelegateVersion,
}Expand description
Push node state is the state push to the remote server.
Fields
id: IThe id of the push node state.
addr: AThe address of the push node state.
meta: &'a [u8]Metadata from the delegate for this push node state.
incarnation: u32The incarnation of the push node state.
state: StateThe state of the push node state.
protocol_version: ProtocolVersionThe protocol version of the push node state is speaking.
delegate_version: DelegateVersionThe delegate version of the push node state is speaking.
Implementations
Sourceimpl<'a, I, A> PushNodeStateRef<'a, I, A>
impl<'a, I, A> PushNodeStateRef<'a, I, A>
Sourcepub const fn incarnation(&self) -> u32
pub const fn incarnation(&self) -> u32
Returns the incarnation of the push node state
Sourcepub const fn protocol_version(&self) -> ProtocolVersion
pub const fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the push node state is speaking
Sourcepub const fn delegate_version(&self) -> DelegateVersion
pub const fn delegate_version(&self) -> DelegateVersion
Returns the delegate version of the push node state is speaking