PushPull

Struct PushPull 

pub struct PushPull<I, A> {
    pub join: bool,
    pub states: Arc<[PushNodeState<I, A>]>,
    pub user_data: Bytes,
}
Push pull message.

Fields

join: bool

Whether the push pull message is a join message.

states: Arc<[PushNodeState<I, A>]>

The states of the push pull message.

user_data: Bytes

The user data of the push pull message.

Implementations

Source

impl<I, A> PushPull<I, A>

pub const fn join(&self) -> bool

Returns whether the push pull message is a join message

pub const fn states(&self) -> &Arc<[PushNodeState<I, A>]>

Returns the states of the push pull message

pub const fn user_data(&self) -> &Bytes

Returns the user data of the push pull message

pub const fn with_join(self, val: bool) -> PushPull<I, A>

Sets whether the push pull message is a join message (Builder pattern)

pub fn with_states(self, val: Arc<[PushNodeState<I, A>]>) -> PushPull<I, A>

Sets the states of the push pull message (Builder pattern)

pub fn with_user_data(self, val: Bytes) -> PushPull<I, A>

Sets the user data of the push pull message (Builder pattern)

Source

impl<I, A> PushPull<I, A>

pub fn new( join: bool, states: impl Iterator<Item = PushNodeState<I, A>>, ) -> PushPull<I, A>

Create a new PushPull message.

pub fn into_components(self) -> (bool, Bytes, Arc<[PushNodeState<I, A>]>)

Consumes the PushPull and returns the states and user data.