PushPullRef

Struct PushPullRef 

pub struct PushPullRef<'a, I, A> {
    pub join: bool,
    pub states: RepeatedDecoder<'a>,
    pub user_data: &'a [u8],
    pub _m: PhantomData<(I, A)>,
}
The reference type of Push pull message.

Fields

join: bool

Whether the push pull message is a join message.

states: RepeatedDecoder<'a>

The states of the push pull message.

user_data: &'a [u8]

The user data of the push pull message.

_m: PhantomData<(I, A)>

Implementations

Source

impl<'a, I, A> PushPullRef<'a, I, A>

pub const fn join(&self) -> bool

Returns whether the push pull message is a join message

pub const fn states(&self) -> &RepeatedDecoder<'a>

Returns the states of the push pull message

pub const fn user_data(&self) -> &'a [u8]

Returns the user data of the push pull message