pub struct RepeatedDecoder<'a> { /* private fields */ }Expand description
An iterator with can yields the reference type of D
Implementations
Sourceimpl<'a> RepeatedDecoder<'a>
impl<'a> RepeatedDecoder<'a>
Sourcepub fn new(tag: u8, wire_type: WireType, src: &'a [u8]) -> RepeatedDecoder<'a>
pub fn new(tag: u8, wire_type: WireType, src: &'a [u8]) -> RepeatedDecoder<'a>
Creates a new RepeatedDecoder with the given tag, source buffer
Sourcepub const fn with_offsets(self, start: usize, end: usize) -> RepeatedDecoder<'a>
pub const fn with_offsets(self, start: usize, end: usize) -> RepeatedDecoder<'a>
Sets the offsets for this decoder.
Sourcepub const fn with_nums(self, nums: usize) -> RepeatedDecoder<'a>
pub const fn with_nums(self, nums: usize) -> RepeatedDecoder<'a>
Sets the number of elements in the buffer.
Sourcepub fn iter<D>(&self) -> RepeatedDecoderIter<'a, D> ⓘ
pub fn iter<D>(&self) -> RepeatedDecoderIter<'a, D> ⓘ
Returns an iterator over the Ds in the collection.