Module queue

Module queue 

The transimit queue implementation.

Structs

TransmitLimitedQueue
Used to queue messages to broadcast to the cluster (via gossip) but limits the number of transmits per message. It also prioritizes messages with lower transmit counts (hence newer messages).

Traits

NodeCalculator
Used to calculate the number of nodes in the cluster.