pub struct TransmitLimitedQueue<B: Broadcast, N> { /* private fields */ }Expand description
Used to queue messages to broadcast to the cluster (via gossip) but limits the number of transmits per message. It also prioritizes messages with lower transmit counts (hence newer messages).
Implementations
Sourceimpl<B: Broadcast, N: NodeCalculator> TransmitLimitedQueue<B, N>
impl<B: Broadcast, N: NodeCalculator> TransmitLimitedQueue<B, N>
Sourcepub fn new(retransmit_mult: usize, calc: N) -> Self
pub fn new(retransmit_mult: usize, calc: N) -> Self
Creates a new TransmitLimitedQueue.
Sourcepub async fn num_queued(&self) -> usize
pub async fn num_queued(&self) -> usize
Returns the number of messages queued.
Sourcepub async fn get_broadcasts(&self, limit: usize) -> TinyVec<B::Message>
pub async fn get_broadcasts(&self, limit: usize) -> TinyVec<B::Message>
Returns the messages can be broadcast.
Sourcepub async fn queue_broadcast(&self, b: B)
pub async fn queue_broadcast(&self, b: B)
Used to enqueue a broadcast