#[non_exhaustive]pub enum ConstDecodeError {
Overflow,
InsufficientData(InsufficientData),
Other(&'static str),
}Expand description
Decoding varint error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Overflow
The buffer does not contain a valid LEB128 encoding.
InsufficientData(InsufficientData)
The buffer does not contain enough data to decode.
Other(&'static str)
A custom error message.
Implementations
Sourceimpl ConstDecodeError
impl ConstDecodeError
Sourcepub const fn overflow() -> ConstDecodeError
pub const fn overflow() -> ConstDecodeError
Creates a new ConstDecodeError::Overflow indicating that the decoded value would overflow the target type.
Sourcepub const fn insufficient_data(available: usize) -> ConstDecodeError
pub const fn insufficient_data(available: usize) -> ConstDecodeError
Creates a new ConstDecodeError::InsufficientData indicating that the buffer does not have enough data
to decode a value.
Sourcepub const fn insufficient_data_with_required(
required: NonZero<usize>,
available: usize,
) -> ConstDecodeError
pub const fn insufficient_data_with_required( required: NonZero<usize>, available: usize, ) -> ConstDecodeError
Creates a new ConstDecodeError::InsufficientData with the required and available bytes.
Panics
Panics if required is not greater than available.
Sourcepub const fn other(msg: &'static str) -> ConstDecodeError
pub const fn other(msg: &'static str) -> ConstDecodeError
Creates a new ConstDecodeError::Other with the given message.
Sourcepub const fn into_decode_error(self) -> DecodeError
pub const fn into_decode_error(self) -> DecodeError
Converts this ConstDecodeError into a DecodeError.
Example
use varing::{ConstDecodeError, DecodeError};
let const_error = ConstDecodeError::other("Other error message");
let error: DecodeError = const_error.into_decode_error();
let const_error_overflow = ConstDecodeError::overflow();
let error_overflow: DecodeError = const_error_overflow.into_decode_error();
let const_error_insufficient = ConstDecodeError::insufficient_data(5);
let error_insufficient: DecodeError = const_error_insufficient.into_decode_error();Trait Implementations
Sourceimpl Clone for ConstDecodeError
impl Clone for ConstDecodeError
Sourcefn clone(&self) -> ConstDecodeError
fn clone(&self) -> ConstDecodeError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstDecodeError
impl Debug for ConstDecodeError
Sourceimpl Display for ConstDecodeError
impl Display for ConstDecodeError
impl Eq for ConstDecodeError
Sourceimpl Error for ConstDecodeError
impl Error for ConstDecodeError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<ConstDecodeError> for DecodeError
impl From<ConstDecodeError> for DecodeError
Sourcefn from(e: ConstDecodeError) -> DecodeError
fn from(e: ConstDecodeError) -> DecodeError
Converts to this type from the input type.
Sourceimpl From<ConstDecodeError> for Error
Available on crate feature std only.
impl From<ConstDecodeError> for Error
Available on crate feature
std only.Sourcefn from(err: ConstDecodeError) -> Error
fn from(err: ConstDecodeError) -> Error
Converts to this type from the input type.
Sourceimpl From<ConstDecodeError> for DecodeError
impl From<ConstDecodeError> for DecodeError
Sourcefn from(err: ConstDecodeError) -> DecodeError
fn from(err: ConstDecodeError) -> DecodeError
Converts to this type from the input type.
Sourceimpl From<InsufficientData> for ConstDecodeError
impl From<InsufficientData> for ConstDecodeError
Sourcefn from(source: InsufficientData) -> ConstDecodeError
fn from(source: InsufficientData) -> ConstDecodeError
Converts to this type from the input type.
Sourceimpl Hash for ConstDecodeError
impl Hash for ConstDecodeError
Sourceimpl PartialEq for ConstDecodeError
impl PartialEq for ConstDecodeError
Sourcefn eq(&self, other: &ConstDecodeError) -> bool
fn eq(&self, other: &ConstDecodeError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ConstDecodeError