#[non_exhaustive]pub enum DecodeError {
Overflow,
InsufficientData(InsufficientData),
Other(Cow<'static, str>),
}Expand description
Decoding varint error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Overflow
The buffer does not contain a valid LEB128 encoding.
InsufficientData(InsufficientData)
The buffer does not contain enough data to decode.
Other(Cow<'static, str>)
Available on crate features
alloc or std only.A custom error message.
Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub const fn overflow() -> DecodeError
pub const fn overflow() -> DecodeError
Creates a new DecodeError::Overflow indicating that the decoded value would overflow the target type.
Sourcepub const fn insufficient_data(available: usize) -> DecodeError
pub const fn insufficient_data(available: usize) -> DecodeError
Creates a new DecodeError::InsufficientData indicating that the buffer does not have enough data
to decode a value.
Sourcepub const fn insufficient_data_with_required(
required: NonZero<usize>,
available: usize,
) -> DecodeError
pub const fn insufficient_data_with_required( required: NonZero<usize>, available: usize, ) -> DecodeError
Creates a new DecodeError::InsufficientData with the required and available bytes.
Panics
Panics if required is not greater than available.