pub struct InsufficientData { /* private fields */ }Expand description
An error that occurs when trying to decode data from a buffer with insufficient data.
This error indicates that a decode operation failed because the buffer does not have enough remaining bytes to decode the value.
Implementations
Sourceimpl InsufficientData
impl InsufficientData
Sourcepub const fn new(available: usize) -> InsufficientData
pub const fn new(available: usize) -> InsufficientData
Creates a new InsufficientData error with only the available bytes.
Sourcepub const fn with_required(
required: NonZero<usize>,
available: usize,
) -> InsufficientData
pub const fn with_required( required: NonZero<usize>, available: usize, ) -> InsufficientData
Creates a new InsufficientData error with the required and available bytes.
Panics
Panics if required is not greater than available.