SubscribleEventDelegate

Struct SubscribleEventDelegate 

pub struct SubscribleEventDelegate<I, A>(/* private fields */);
Used to enable an application to receive events about joins and leaves over a subscriber instead of a direct function call.

Implementations

Source

impl<I, A> SubscribleEventDelegate<I, A>

pub fn unbounded() -> (Self, EventSubscriber<I, A>)

Creates a new EventDelegate and unbounded subscriber.

pub fn bounded(capacity: usize) -> (Self, EventSubscriber<I, A>)

Creates a new EventDelegate and bounded subscriber.

Care must be taken that events are processed in a timely manner from the channel, since this delegate will block until an event can be sent.