pub struct NodeState<I, A> {
pub id: I,
pub addr: A,
pub meta: Meta,
pub state: State,
pub protocol_version: ProtocolVersion,
pub delegate_version: DelegateVersion,
}Expand description
Represents a node in the cluster
Fields
id: IThe id of the node.
addr: AThe address of the node.
meta: MetaMetadata from the delegate for this node.
state: StateState of the node.
protocol_version: ProtocolVersionThe protocol version of the node is speaking.
delegate_version: DelegateVersionThe delegate version of the node is speaking.
Implementations
Sourceimpl<I, A> NodeState<I, A>
impl<I, A> NodeState<I, A>
Sourcepub const fn protocol_version(&self) -> ProtocolVersion
pub const fn protocol_version(&self) -> ProtocolVersion
Returns the protocol version of the node is speaking
Sourcepub const fn delegate_version(&self) -> DelegateVersion
pub const fn delegate_version(&self) -> DelegateVersion
Returns the delegate version of the node is speaking
Sourcepub fn with_address(self, val: A) -> NodeState<I, A>
pub fn with_address(self, val: A) -> NodeState<I, A>
Sets the address of the node (Builder pattern)
Sourcepub fn with_meta(self, val: Meta) -> NodeState<I, A>
pub fn with_meta(self, val: Meta) -> NodeState<I, A>
Sets the meta of the node (Builder pattern)
Sourcepub const fn with_state(self, val: State) -> NodeState<I, A>
pub const fn with_state(self, val: State) -> NodeState<I, A>
Sets the state of the node (Builder pattern)
Sourcepub const fn with_protocol_version(
self,
val: ProtocolVersion,
) -> NodeState<I, A>
pub const fn with_protocol_version( self, val: ProtocolVersion, ) -> NodeState<I, A>
Sets the protocol version of the node is speaking (Builder pattern)
Sourcepub const fn with_delegate_version(
self,
val: DelegateVersion,
) -> NodeState<I, A>
pub const fn with_delegate_version( self, val: DelegateVersion, ) -> NodeState<I, A>
Sets the delegate version of the node is speaking (Builder pattern)
Sourceimpl<I, A> NodeState<I, A>
impl<I, A> NodeState<I, A>
Sourcepub const fn new(id: I, addr: A, state: State) -> NodeState<I, A>
pub const fn new(id: I, addr: A, state: State) -> NodeState<I, A>
Construct a new node with the given name, address and state.
Sourcepub fn set_address(&mut self, addr: A) -> &mut NodeState<I, A>
pub fn set_address(&mut self, addr: A) -> &mut NodeState<I, A>
Sets the address of the node state
Sourcepub fn set_protocol_version(
&mut self,
protocol_version: ProtocolVersion,
) -> &mut NodeState<I, A>
pub fn set_protocol_version( &mut self, protocol_version: ProtocolVersion, ) -> &mut NodeState<I, A>
Set the protocol version of the alive message is speaking.
Sourcepub fn set_delegate_version(
&mut self,
delegate_version: DelegateVersion,
) -> &mut NodeState<I, A>
pub fn set_delegate_version( &mut self, delegate_version: DelegateVersion, ) -> &mut NodeState<I, A>
Set the delegate version of the alive message is speaking.
Sourceimpl<I, A> NodeState<I, A>where
I: CheapClone,
A: CheapClone,
impl<I, A> NodeState<I, A>where
I: CheapClone,
A: CheapClone,