pub struct PushPull<I, A> {
pub join: bool,
pub states: Arc<[PushNodeState<I, A>]>,
pub user_data: Bytes,
}Expand description
Push pull message.
Fields
join: boolWhether the push pull message is a join message.
states: Arc<[PushNodeState<I, A>]>The states of the push pull message.
user_data: BytesThe user data of the push pull message.
Implementations
Sourceimpl<I, A> PushPull<I, A>
impl<I, A> PushPull<I, A>
Sourcepub const fn states(&self) -> &Arc<[PushNodeState<I, A>]>
pub const fn states(&self) -> &Arc<[PushNodeState<I, A>]>
Returns the states of the push pull message
Sourcepub const fn with_join(self, val: bool) -> PushPull<I, A>
pub const fn with_join(self, val: bool) -> PushPull<I, A>
Sets whether the push pull message is a join message (Builder pattern)
Sourcepub fn with_states(self, val: Arc<[PushNodeState<I, A>]>) -> PushPull<I, A>
pub fn with_states(self, val: Arc<[PushNodeState<I, A>]>) -> PushPull<I, A>
Sets the states of the push pull message (Builder pattern)
Sourcepub fn with_user_data(self, val: Bytes) -> PushPull<I, A>
pub fn with_user_data(self, val: Bytes) -> PushPull<I, A>
Sets the user data of the push pull message (Builder pattern)
Sourceimpl<I, A> PushPull<I, A>
impl<I, A> PushPull<I, A>
Sourcepub fn new(
join: bool,
states: impl Iterator<Item = PushNodeState<I, A>>,
) -> PushPull<I, A>
pub fn new( join: bool, states: impl Iterator<Item = PushNodeState<I, A>>, ) -> PushPull<I, A>
Create a new PushPull message.
Sourcepub fn into_components(self) -> (bool, Bytes, Arc<[PushNodeState<I, A>]>)
pub fn into_components(self) -> (bool, Bytes, Arc<[PushNodeState<I, A>]>)
Consumes the PushPull and returns the states and user data.